angular.module('beamng.apps')
.directive('brakeThermalMinimal', ['UiUnits', function (UiUnits) {
  return {
    templateUrl: 'modules/apps/BrakeThermalMinimal/app.html',
    replace: true,
    restrict: 'EA',
    scope: true,
    controller: ['$log', '$scope', 'bngApi', 'StreamsManager', function ($log, $scope, bngApi, StreamsManager) {
      var streamsList = ['wheelThermalData'];
      StreamsManager.add(streamsList);
      $scope.$on('$destroy', function () {
        StreamsManager.remove(streamsList);
      });

      $scope.gearText = '';
      $scope.wheels = [];
      $scope.displayWheel1 = null;
      $scope.displayWheel2 = null;

      var _reset = function () {
        $scope.$evalAsync(function () {
          $scope.wheels = [];
          $scope.displayWheel1 = null;
          $scope.displayWheel2 = null;
        });
      };

      $scope.$on('streamsUpdate', function (event, data) {
        if (!data.wheelThermalData) {
          $scope.data = [];
          return;
        }

        if ($scope.wheels.length < 1) {
          var wheelKeys = Object.keys(data.wheelThermalData.wheels);
          $scope.wheels = wheelKeys;
          $scope.displayWheel1 = wheelKeys[wheelKeys.length-1];
          $scope.displayWheel2 = wheelKeys[0];
          $scope.$digest();
          return;
        }

        if ( !($scope.displayWheel1 in data.wheelThermalData.wheels) ||
             !($scope.displayWheel2 in data.wheelThermalData.wheels)) {
          _reset();
          return;
        }

        $scope.$evalAsync(function () {
          var currentWheels = Object.keys(data.wheelThermalData.wheels);
          if (currentWheels.length != $scope.wheels.length)
            $scope.wheels = currentWheels;

          $scope.data = makeDataDisplayable(data.wheelThermalData, $scope.displayWheel1, $scope.displayWheel2);
        });
      });

      $scope.$on('VehicleFocusChanged', _reset);
      $scope.$on('VehicleReset', _reset);

      var makeDataDisplayable = function (data, displayWheel1, displayWheel2) {
        return [{
              name: 'Temp',
              str1: UiUnits.buildString('temperature', data.wheels[displayWheel1].brakeSurfaceTemperature, 0),
              str2: UiUnits.buildString('temperature', data.wheels[displayWheel2].brakeSurfaceTemperature, 0),
          }, {
              name: 'Effect',
              str1: data.wheels[displayWheel1].finalBrakeEfficiency.toFixed(2),
              str2: data.wheels[displayWheel2].finalBrakeEfficiency.toFixed(2),
              warn1: (data.wheels[displayWheel1].finalBrakeEfficiency <= 0.90),
              warn2: (data.wheels[displayWheel2].finalBrakeEfficiency <= 0.90),
              error1: (data.wheels[displayWheel1].finalBrakeEfficiency < 0.85),
              error2: (data.wheels[displayWheel2].finalBrakeEfficiency < 0.85)		  
          }
        ];
      }
    }]
  };
}]);
